colour.models.dataset.smptec_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.smptec_rgb Module

## SMPTE-C RGB Colourspace

Defines the SMPTE-C RGB colourspace:

- `SMPTE_C_RGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://standards.smpte.org/content/978-1-61482-164-9/rp-145-2004/SEC1.body.pdf (Last accessed 13 April 2014)

`colour.models.dataset.smptec_rgb.` `SMPTE_C_RGB_PRIMARIES` = array([[ 0.63 , 0.34 ], [ 0.31 , 0.595], [ 0.155, 0.07 ]])

  SMPTE-C RGB colourspace primaries.

  SMPTE_C_RGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.smptec_rgb.` `SMPTE_C_RGB_WHITEPOINT` = (0.31271, 0.32902)

  SMPTE-C RGB colourspace whitepoint.

  SMPTE_C_RGB_WHITEPOINT : tuple

`colour.models.dataset.smptec_rgb.` `SMPTE_C_RGB_TO_XYZ_MATRIX` = array([[ 0.39351682, 0.36526675, 0.19164498], [ 0.21237416, 0.7010765 , 0.08654934], [ 0.0187389 , 0.11193658, 0.95822489]])

  SMPTE-C RGB colourspace to CIE XYZ colourspace matrix.

  SMPTE_C_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.smptec_rgb.` `XYZ_TO_SMPTE_C_RGB_MATRIX` = array([[ 3.50603966, -1.73980878, -0.54406391], [-1.06902218, 1.97773194, 0.03517058], [ 0.05631598, -0.19700851, 1.05012747]])

  CIE XYZ colourspace to SMPTE-C RGB colourspace matrix.

  XYZ_TO_SMPTE_C_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.smptec_rgb.` `SMPTE_C_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to SMPTE-C RGB colourspace.

  SMPTE_C_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.smptec_rgb.` `SMPTE_C_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from SMPTE-C RGB colourspace to linear.

  SMPTE_C_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.smptec_rgb.` `SMPTE_C_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e297d0>

  SMPTE-C RGB colourspace.

  SMPTE_C_RGB_COLOURSPACE : RGB_Colourspace